pub struct ReloadableShaderSource {
pub static_source: String,
pub path: String,
}Expand description
Stores both a static source code for a shader as well as path to its file in development. This is used for automatic shader hot reloading.
Fields
static_source: Stringpath: StringAuto Trait Implementations
impl Freeze for ReloadableShaderSource
impl RefUnwindSafe for ReloadableShaderSource
impl Send for ReloadableShaderSource
impl Sync for ReloadableShaderSource
impl Unpin for ReloadableShaderSource
impl UnsafeUnpin for ReloadableShaderSource
impl UnwindSafe for ReloadableShaderSource